changeset 18898:fa6d68fd97b1

(fixed, excerpt): Define with defface. No longer queries X server to find a "fixed" font; that was too slow and didn't work for everyone.
author Richard M. Stallman <rms@gnu.org>
date Mon, 21 Jul 1997 19:06:57 +0000
parents 84972fa25ac1
children 3cd2c58b1d6f
files lisp/enriched.el
diffstat 1 files changed, 16 insertions(+), 17 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/enriched.el	Mon Jul 21 18:42:03 1997 +0000
+++ b/lisp/enriched.el	Mon Jul 21 19:06:57 1997 +0000
@@ -59,23 +59,22 @@
 ;;; Set up faces & display table
 ;;;
 
-;; A slight cheat - all emacs's faces are fixed-width.  
-;; The idea is just to pick one that looks different from the default.
-(if (internal-find-face 'fixed)
-    nil
-  (make-face 'fixed)
-  (if window-system
-      (set-face-font 'fixed
-		     (car (or (x-list-fonts "*fixed-medium*" 
-					    'default (selected-frame))
-			      (x-list-fonts "*fixed*" 
-					    'default (selected-frame)))))))
-			      
-(if (internal-find-face 'excerpt)
-    nil
-  (make-face 'excerpt)
-  (if window-system
-      (make-face-italic 'excerpt nil t)))
+;; Emacs doesn't have a "fixed" face by default, since all faces currently
+;; have to be fixed-width.  So we just pick one that looks different from the
+;; default.
+(defface fixed
+  '((t (:bold t)))
+  "Face used for text that must be shown in fixed width.
+Currently, emacs can only display fixed-width fonts, but this may change.
+This face is used for text specifically marked as fixed-width, for example
+in text/enriched files."
+  :group 'enriched)
+
+(defface excerpt
+  '((t (:italic t)))
+  "Face used for text that is an excerpt from another document.
+This is used in enriched-mode for text explicitly marked as an excerpt."
+  :group 'enriched)
 
 (defconst enriched-display-table (or (copy-sequence standard-display-table)
 				     (make-display-table)))